.. _source:


.. raw:: html

     <br><br>


.. title:: Source


**OTPCR**

.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    president.cache
    president.config
    president.client
    president.cmds
    president.console
    president.decoder
    president.default
    president.encoder
    president.errors
    president.event
    president.fleet
    president.group
    president.log
    president.main
    president.object
    president.parse
    president.persist
    president.reactor
    president.repeater
    president.thread
    president.timer
    president.utils


.. raw:: html

     <br>


**MODULES**


.. raw:: html

     <br>

.. autosummary::
    :toctree: 
    :template: base.rst

    president.modules.cmd
    president.modules.err
    president.modules.irc
    president.modules.log
    president.modules.mod
    president.modules.req
    president.modules.rss
    president.modules.tdo
    president.modules.thr
